==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
export let GotFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GotFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GotFocusEventArgsDescriptionMetadata.a == null) {
                GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
            }
            if (a.j(GotFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GotFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GotFocusEventArgsDescriptionMetadata.b(a);
            a.aa("GotFocusEventArgs", () => new GotFocusEventArgsDescription());
            a.z("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
        }
    }
    GotFocusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GotFocusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GotFocusEventArgsDescription } from "./GotFocusEventArgsDescription";
/**
 * @hidden
 */
export let GotFocusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GotFocusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GotFocusEventArgsDescriptionMetadata.a == null) {
                GotFocusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GotFocusEventArgsDescriptionMetadata.c(GotFocusEventArgsDescriptionMetadata.a);
            }
            if (a.k(GotFocusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GotFocusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GotFocusEventArgsDescriptionMetadata.b(a);
            a.ac("GotFocusEventArgs", () => new GotFocusEventArgsDescription());
            a.ab("GotFocusEventArgs", GotFocusEventArgsDescriptionMetadata.a);
        }
    }
    GotFocusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GotFocusEventArgsDescriptionMetadata, 'GotFocusEventArgsDescriptionMetadata');
    GotFocusEventArgsDescriptionMetadata.a = null;
    return GotFocusEventArgsDescriptionMetadata;
})();
